@@ -1,9 +1,9 @@
 #!/bin/sh
 
-mount() {
+mountpartitions() {
 for partitions in "`awk '$4~"[0-9]$"{print $4}' /proc/partitions | grep -v "mmcblk*"`"
 	do mkdir -p /media/$partitions
-	mount /dev/$partitions /media/$partitions
+	/bin/mount /dev/$partitions /media/$partitions
 done
 }
 
@@ -16,7 +16,7 @@ done
 
 if [ "$1" = "--mount" ]
 	then
-		mount
+		mountpartitions
 fi
 
 if [ "$1" = "--unmount" ]
