@@ -8,6 +8,7 @@
 #include <QIODevice>
 #include <QFile>
 #include <QtGui>
+#include <QUrl>
 #include <stdlib.h>
 #ifdef Q_WS_MAEMO_5
 #include <QMaemo5InformationBox>
@@ -36,13 +37,14 @@ private slots:
     void hostmodeFS();
     void hostmodeLS();
     void hostmodeHS();
-    void mountdevsda1();
     void vbusOn();
     void vbusOff();
     void kernelmessages();
     void orientationChanged();
     void enumerate();
     void helpWindow();
+    void mount();
+    void unmount();
 };
 
 #endif // MAINWINDOW_H
